/**
 * Definitions of default handlers:
 * Unknown protocols
 * Error messages
 *
 * This file is part of DCC Monitor.
 *
 * Copyright 2007, 2008 Peter Lebbing <peter@digitalbrains.com>
 *
 * DCC Monitor is free software: you can redistribute it and/or modify
 * it under the terms of the GNU General Public License as published by
 * the Free Software Foundation, either version 3 of the License, or
 * (at your option) any later version.
 * 
 * DCC Monitor is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 * GNU General Public License for more details.
 *
 * You should have received a copy of the GNU General Public License
 * along with DCC Monitor.  If not, see <http://www.gnu.org/licenses/>.
 */

#ifndef FILE_DEFAULT_HANDLERS_H
#define FILE_DEFAULT_HANDLERS_H

#include "global.h"

/**
 * The default protocol handler, which gets called for any protocol that is not
 * handled.
 *
 * Reports an error to the user. Returns with zero to end protocol handler chain
 * traversal.
 */
extern int unknown_proto_handler (struct s_frame* frame);

/**
 * The default error handler
 *
 * Displays an error message for the errors returned by comm_get_frame() and
 * returns 0 to end the error handler chain.
 *
 * Errors END_INPUT and E_GARBAGE end the program.
 */
extern int default_err_handler (int error, struct s_frame* frame);

#endif // ndef FILE_DEFAULT_HANDLERS_H
