/**
 * Definitions for communication routines for loading and saving frames from/to
 * a file.
 *
 * This file is part of DCC Monitor.
 *
 * Copyright 2007, 2008 Peter Lebbing <peter@digitalbrains.com>
 *
 * DCC Monitor is free software: you can redistribute it and/or modify
 * it under the terms of the GNU General Public License as published by
 * the Free Software Foundation, either version 3 of the License, or
 * (at your option) any later version.
 * 
 * DCC Monitor is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 * GNU General Public License for more details.
 *
 * You should have received a copy of the GNU General Public License
 * along with DCC Monitor.  If not, see <http://www.gnu.org/licenses/>.
 */
#ifndef FILE_FILE_COMM_PROTO_H 
#define FILE_FILE_COMM_PROTO_H 

#include <stdint.h>
#include <stdio.h>
#include "global.h"
#include "comm_proto.h"

/**
 * Set the given stream to be the input stream, which should be a previously
 * saved communication file.
 *
 * The file header is checked for correctness.
 */
extern void filecomm_set_input_stream (FILE *stream);

/**
 * Set the given stream to be the output stream, which is where all received
 * communication frames will be saved.
 *
 * If argument flush is non-zero, the stream will be flushed after every complete
 * packet is written.
 *
 * The file header is written; write errors cause program termination.
 */
extern void filecomm_set_output_stream (FILE *stream, int flush);

/**
 * Return the next frame from the input stream
 *
 * Return value is 0 for success, or:
 * END_INPUT: End of input stream reached
 * E_BIGFRAME: Frame received was too large
 * E_NULLFRAME: Just a frame start byte
 * E_TINYFRAME: Frame received was too small
 * E_PARITY: Frame failed parity check (frame parity != DCC parity!)
 */
extern comm_get_frame_function filecomm_get_frame;

/**
 * Write the received frame to the output stream.
 *
 * Argument get_retval is the return value of the comm_get_frame_function that
 * produced the frame.
 *
 * Write errors cause program termination.
 */
extern void filecomm_write_frame (int8_t get_retval, struct s_frame *frame);

#endif // ndef FILE_FILE_COMM_PROTO_H 
