/**
 * Global definitions for the DCC Monitor PC program. 
 *
 * This file is part of DCC Monitor.
 *
 * Copyright 2007, 2008 Peter Lebbing <peter@digitalbrains.com>
 *
 * DCC Monitor is free software: you can redistribute it and/or modify
 * it under the terms of the GNU General Public License as published by
 * the Free Software Foundation, either version 3 of the License, or
 * (at your option) any later version.
 * 
 * DCC Monitor is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 * GNU General Public License for more details.
 *
 * You should have received a copy of the GNU General Public License
 * along with DCC Monitor.  If not, see <http://www.gnu.org/licenses/>.
 */

#ifndef FILE_GLOBAL_H
#define FILE_GLOBAL_H

#include <stdint.h>
#include <stddef.h>
#include <time.h>

// MAX_FRAME_SIZE: A complete frame is never bigger than this many bytes of 
// data
#define MAX_FRAME_SIZE 12

// The maximum number of addresses supported by the communication protocol
#define MAX_ADDRS 8

// The maximum number of protocols supported by the communication protocol
#define MAX_PROTOS 16

// Baudrate setting, using constants from termios.h
#define UART_BAUD B57600

// Verbosity, a bit for every optional verbosity
extern unsigned int verbosity;

// All verbosity switches; bitmasks for verbosity variable
// DCC protocol
#define VERB_DCC (1 << 0)
// Management protocol
#define VERB_MANAG (1 << 1)
// Tests run on boards
#define VERB_TEST (1 << 2)
// RS-bus protocol
#define VERB_RS (1 << 3)
// Error messages
#define VERB_ERR (1 << 4)

/**
 * Holds all the information on a frame
 */
struct s_frame {
  uint8_t addr; // Address that sent the frame
  uint8_t proto; // Protocol of data in frame
  time_t time; // Time we received the frame
  size_t len; // Length of data
  uint8_t data[MAX_FRAME_SIZE + 2]; // The frame data, plus some leeway for processing
};

#endif // ndef FILE_GLOBAL_H
